@@ -1,7 +1,7 @@
 /*
  * EDMA: Entorno de Desarrollo Modular y Abierto
  * Object Oriented and Componetware Framework
- * Copyright (C) 1998, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2010
+ * Copyright (C) 1998, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2010, 2013
  *    David Mart.nez Oliveira
  *
  * This file is part of EDMA.
@@ -80,6 +80,10 @@ extern "C"{
                      }}
 #endif
 //#define EDMA_TRY_END edma_free_obj (val);}
+
+/* Easy object data access */
+#define EDMA_THAT(type,id) type that = (type) edma_get_data_ref (id)
+
   /* Generic GNU/EDMA Error Constant. This will change*/
 #define EDMA_ERROR     -1
   /*
@@ -390,6 +394,9 @@ extern "C"{
   ESint32 EDMAPROC edma_merge_subclass_obj (OBJID,EPChar,OBJID);
   ESint32 EDMAPROC edma_free_subclass_obj (OBJID,EPChar);
 
+OBJID EDMAPROC edma_remove_subclass (OBJID id, EPChar apoint1, EUint32 flag);
+OBJID EDMAPROC edma_remove_superclass (OBJID id, EPChar apoint1, EUint32 flag);
+
   /* Level 3 Primitives */  
   EPVoid  EDMAPROC edma_wprop3_old (OBJID,EPChar,...);
   EPVoid  EDMAPROC edma_rprop3_old (OBJID,EPChar,...);
@@ -548,6 +555,9 @@ extern "C"{
   EUint32 EDMAPROC EDMAEnd(void);   
   EUint32 EDMAPROC EDMAInit(void);   
 
+#define edma_init EDMAInit
+#define edma_end  EDMAEnd
+
   ESint32 EDMAPROC  edma_add_std_repo (EPChar repo_name);
   ESint32 EDMAPROC   edma_add_app_repos ();
 
