@@ -1,7 +1,7 @@
 /*
  * EDMA: Entorno de Desarrollo Modular y Abierto
  * Object Oriented and Componetware Framework
- * Copyright (C) 1998, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2010
+ * Copyright (C) 1998, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2010, 2013
  *    David Martnez Oliveira
  *
  * This file is part of EDMA.
@@ -930,3 +930,103 @@ edma_insert_subobject (OBJID id, OBJID subobj, EPChar apoint1, EPChar apoint2)
   return subobj;
 }
 /************************************************************************/
+
+
+/* edma_remove_subclass */
+OBJID EDMAPROC
+edma_remove_subclass (OBJID id, EPChar apoint1, EUint32 flag)
+{
+  ESint32    n, i;  
+  OBJID      subobj, superobj;
+
+  /* FIXME: We should write a parameter-checker wrapper and 
+   * make this function internal */
+  if ((edma_check_obj_id (id, "edma_remove_subclass")) == -1)
+    return -1;
+
+  if (apoint1 == NULL)
+    {
+      edma_log ("%s", "[edma_remove_subclass] WARNNING:: Invalid Anchor point");
+      return -1;
+    }
+
+  // Locate the subobject using the anchor point
+  if ((subobj = edma_downcast_obj (id, apoint1)) < 0)
+    {
+      edma_log ("Class/Anchor Point '%s' not found on object %d (%s)",
+		apoint1, id, gClass[gObj[id]->IdClass]->ClassName);
+      return 0;
+    }
+
+  
+  /* Remove link from father to subobject */
+  for (i = 0; i < gObj[subobj]->nUpTable; i++)
+    {
+      /* For each father we check if we can reach the original object
+       * if so, we remove the link
+       */
+      if ((superobj = edma_upcast_obj (subobj, gClass[gObj[id]->IdClass]->ClassName)) < 0) continue;
+      /* There is a link to the root object through this uplink... remove it */
+      edma_remove_superclass_ap (subobj, gObj[subobj]->UpTable[i].Id);
+    }
+
+ 
+  /* Remove subobject */
+  if (flag)
+    {
+      edma_free_obj (subobj);
+      return 0;
+    }
+  
+  return subobj;
+}
+
+
+OBJID EDMAPROC
+edma_remove_superclass (OBJID id, EPChar apoint1, EUint32 flag)
+{
+  ESint32    n, i;  
+  OBJID      subobj, superobj;
+
+  /* FIXME: We should write a parameter-checker wrapper and 
+   * make this function internal */
+  if ((edma_check_obj_id (id, "edma_remove_subclass")) == -1)
+    return -1;
+
+  if (apoint1 == NULL)
+    {
+      edma_log ("%s", "[edma_remove_subclass] WARNNING:: Invalid Anchor point");
+      return -1;
+    }
+
+  // Locate the superobject using the anchor point
+  if ((subobj = edma_upcast_obj (id, apoint1)) < 0)
+    {
+      edma_log ("Class/Anchor Point '%s' not found on object %d (%s)",
+		apoint1, id, gClass[gObj[id]->IdClass]->ClassName);
+      return 0;
+    }
+
+  
+  /* Remove link from father to subobject */
+  for (i = 0; i < gObj[subobj]->nDownTable; i++)
+    {
+      /* For each father we check if we can reach the original object
+       * if so, we remove the link
+       */
+      if ((superobj = edma_downcast_obj (subobj, gClass[gObj[id]->IdClass]->ClassName)) < 0) continue;
+      /* There is a link to the root object through this uplink... remove it */
+      edma_remove_subclass_ap (subobj, gObj[subobj]->DownTable[i].Id);
+    }
+
+ 
+  /* Remove subobject */
+  if (flag)
+    {
+      edma_free_obj (subobj);
+      return 0;
+    }
+  
+  return subobj;
+}
+
