@@ -1,7 +1,7 @@
 /*
  * EDMA: Entorno de Desarrollo Modular y Abierto
  * Object Oriented and Componetware Framework
- * Copyright (C) 1998, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2010
+ * Copyright (C) 1998, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2010, 2013
  *    David Martnez Oliveira
  *
  * This file is part of EDMA.
@@ -306,7 +306,8 @@ EDMAIni (void)
   /* Load system repositories */
   edma_repo_add_shared_repo ();
 
-
+  /* Load default system repositories if any */
+  edma_add_default_repos ();
 
   edma_printf ("%s", "EDMA Startup process... OK");
 
@@ -477,12 +478,13 @@ _edma_init_global_data ()
       
       GVar->GetClassEMI = 0;
       
+#if 0
       /* Default IDF parser init */
       strncpy (GVar->SubSystem[SS_INGRIDF][0].Id, "EDMAIDF", 7);
       GVar->SubSystem[SS_INGRIDF][0].IdClass = -1;
       
       GVar->SubSystem[SS_SIU][0].IdClass = -1;
-      
+#endif      
       /*pthread_mutex_init (&GVar->class_mutex, NULL);*/
       edma_log ("Max Classes [%d + %d] | Max Objects [%d] | "
 		"Max Parsers [%d] | Max Proxies [%d]",
@@ -497,6 +499,7 @@ _edma_init_global_data ()
   if (GVar->SystemPath[0] == 0)
     strncpy (GVar->SystemPath, GNUEDMADIR, EDMA_PATH_LEN);
 
+  edma_subsystem_init ();
   /* We init system tables */
   _edma_ini_sys_table (GVar->SystemPath);
   
