@@ -1,7 +1,7 @@
 /*
  * EDMA: Entorno de Desarrollo Modular y Abierto
  * Object Oriented and Componetware Framework
- * Copyright (C) 1998, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2010
+ * Copyright (C) 1998, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2010, 2013
  *    David Martnez Oliveira
  *
  * This file is part of EDMA.
@@ -965,6 +965,89 @@ edma_set_obj_final (OBJID IdObj,EUint32 i)
  *   Interchanges two objects
  */
 
+ESint32 EDMAPROC
+edma_swap_obj (OBJID id, OBJID new_id)
+{
+  POBJ     current;
+  OBJID    aux;
+  ESint32  i, j;
+  void     *p;
+  
+  if ((edma_check_obj_id (id, "edma_swap_obj")) == -1)
+    return -1;
+
+  if ((edma_check_obj_id (new_id, "edma_swap_obj")) == -1)
+    return -1;
+
+  /* Update links for first object */
+  for (i = 0; i < gObj[id]->nUpTable; i++)
+    {
+      aux = gObj[id]->UpTable[i].Obj;
+      //if (aux == id) continue;
+      for (j = 0; j < gObj[aux]->nDownTable; j++)
+	if (gObj[aux]->DownTable[j].Obj == id)
+	  {
+	    gObj[aux]->DownTable[j].Obj = new_id;
+	  }
+    }      
+
+  for (i = 0; i < gObj[id]->nDownTable; i++)
+    {
+      aux = gObj[id]->DownTable[i].Obj;      
+      //if (aux == id) continue;
+      for (j = 0; j < gObj[aux]->nUpTable; j++)
+	if (gObj[aux]->UpTable[j].Obj == id)
+	  {
+	    gObj[aux]->UpTable[j].Obj = new_id;
+	  }
+    }      
+
+
+  for (i = 0; i < gObj[new_id]->nUpTable; i++)
+    {
+      aux = gObj[new_id]->UpTable[i].Obj;
+      if (aux == new_id) 
+	{
+	  aux = id;
+	}
+
+      for (j = 0; j < gObj[aux]->nDownTable; j++)
+	if (gObj[aux]->DownTable[j].Obj == new_id)
+	  {
+	    gObj[aux]->DownTable[j].Obj = id;
+	  }
+    }      
+
+  for (i = 0; i < gObj[new_id]->nDownTable; i++)
+    {
+      aux = gObj[new_id]->DownTable[i].Obj;
+      if (aux == new_id) 
+	{
+	  aux = id;
+	  continue;
+	}
+      for (j = 0; j < gObj[aux]->nUpTable; j++)
+	if (gObj[aux]->UpTable[j].Obj == new_id)
+	  {
+	    gObj[aux]->UpTable[j].Obj = id;
+	  }
+
+    }      
+
+
+
+  /* Now interchange ids*/
+  current = gObj[id];
+  gObj[id] = gObj[new_id];
+  gObj[new_id] = current;
+
+  gObj[id]->IdObj = id;
+  gObj[new_id]->IdObj = new_id;
+
+
+  return 0;
+}
+#if 0
 ESint32 EDMAPROC
 edma_swap_obj (OBJID id, OBJID new_id)
 {
@@ -1022,7 +1105,7 @@ edma_swap_obj (OBJID id, OBJID new_id)
 
   return 0;
 }
-
+#endif
 
 
 
