@@ -1,7 +1,7 @@
 /*
  * EDMA: Entorno de Desarrollo Modular y Abierto
  * Object Oriented and Componetware Framework
- * Copyright (C) 1998, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2010
+ * Copyright (C) 1998, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2010, 2013
  *    David Martnez Oliveira
  *
  * This file is part of EDMA.
@@ -427,6 +427,12 @@ edma_load_registry (EPChar base_dir, EPChar fname)
   EDMA_REPO   repo;
   
   edma_log ("%s: base_dir: '%s'  name: '%s'\n", __FUNCTION__, base_dir, fname);
+  /* Check if repo already exist */
+  if (edma_repo_manager_get_repo_by_name (base_dir, fname) != NULL)
+    {
+      edma_log ("Repo already loaded... Skipping\n");
+      return 0;
+    }
   /* Registe Shared repo*/
   if ((repo = edma_repo_new (EDMA_LOCAL_REPO, base_dir, fname)) == NULL)
     {
@@ -659,7 +665,7 @@ ESint32  EDMAPROC
 edma_repo_add_shared_repo ()
 {
   EDMA_REPO     repo;
-
+  int           i;
 
   edma_log ("%s", "+ Adding GNU/EDMA Shared Repository...");
   
@@ -684,6 +690,15 @@ edma_repo_add_shared_repo ()
       /* Read System-wide class register */
       GVar->nClases = _edma_load_registry (repo);
     }
+  else
+    {
+      /* Subsystems are stored per-process so we need to register 
+       * the subsystem provided by shared classes */
+      for (i = 0; i < GVar->nClases; i++)
+	{
+	  _edma_idf_set_subsystems (i);
+	}
+    }
   
   return 0;
 }
@@ -777,7 +792,8 @@ edma_repo_manager_get_repo_by_name (EPChar base_dir, EPChar fname)
     }
   if (i == num_repos)
     {
-      edma_printf_err ("[%s] Repository '%s' not found", __FUNCTION__, fname);
+      //edma_printf_err ("[%s] Repository '%s' not found", __FUNCTION__, fname);
+      edma_log ("[%s] Repository '%s' not found", __FUNCTION__, fname);
       return NULL;
     }
   return repo_list[i];
@@ -868,6 +884,42 @@ edma_add_app_repos ()
 
 }
 
+ESint32   EDMAPROC   
+edma_add_default_repos ()
+{
+  FILE *f;
+  char     repo_dir[1024];
+  char     fname[1024];
+  char     buffer[1024];
+  int      n = 0;
+
+  edma_log ("%s", "Trying to load default system repository list...");
+  snprintf (fname, 1024, "%s/etc/edma_repos.lst", GVar->SystemPath);
+  /* Open File and register contained standard reports */
+  if ((f = fopen (fname, "rt")) == NULL)
+    {
+      // No private repo list... just return silently
+      edma_log ("%s", "No repository list found...\n");
+      return 0;
+    }
+  snprintf (repo_dir, 1024, "%s/share/", GVar->SystemPath);
+  while (!feof (f))
+    {
+      if (!fgets (buffer, 1024, f)) break;
+      buffer[strlen(buffer) - 1] = 0;
+      if (buffer[0] == ';') continue;
+      if (strlen (buffer) == 0) continue;
+      edma_log ("** Adding repository: '%s'", buffer);
+      edma_load_registry (repo_dir, buffer);
+      n++;
+    }
+  fclose (f);
+  edma_log ("%d default repositories loaded\n", n);
+  return 0;
+
+}
+
+
 ESint32  EDMAPROC  
 edma_repo_add_system_repo ()
 {
