@@ -1,7 +1,7 @@
 /*
  * EDMA: Entorno de Desarrollo Modular y Abierto
  * Object Oriented and Componetware Framework
- * Copyright (C) 1998, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2010
+ * Copyright (C) 1998, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2010, 2013
  *    David Martnez Oliveira
  *
  * This file is part of EDMA.
@@ -27,7 +27,8 @@
 
 #ifdef __cplusplus
 extern "C" {
-#endif 
+#endif
+  ESint32 EDMAPROC edma_subsystem_init () ;
   ESint32 EDMAPROC edma_subsystem_get_item (ESint32, EPChar);
   ESint32 EDMAPROC edma_subsystem_add_item (ESint32, EPChar,EPChar);
   ESint32 EDMAPROC edma_subsystem_get_num_items (ESint32);
